@@ -16,11 +16,16 @@ function(x, fun, filename='', ...) {
 		stop('RasterLayer has no cell values in memory or on disk')
 	}
 
+	return( calc(stack(x), fun, filename=filename, ...) )
+	
+	
+	# ignored for now..
+	
 	test = try(fun(x[1]), silent=TRUE)
 	if (class(test) == 'try-error') {
 		stop("function 'fun' is not valid here")
 	}
-	if (length(fun(1)) > 1) { 
+	if (length(test) > 1) { 
 		out <- brick(x)
 	} else {
 		out <- raster(x)
