@@ -9,16 +9,9 @@ if (!isGeneric("persp")) {
 }	
 
 setMethod("persp", signature(x='RasterLayer'), 
-	function(x, maxpixels=100000, ...)  {
-		if (dataContent(x) != 'all') { 
-#	to do: should  test if can read, else sample
-			if (canProcessInMemory(x, 2)) {
-				x <- readAll(x) 
-			} else {
-				x <- sampleRegular(x, size=maxpixels, asRaster=TRUE, corners=TRUE)
-			}
-		}
-		value <- t((values(x, format='matrix'))[nrow(x):1,])
+	function(x, maxpixels=100000, extent=NULL, ...)  {
+		x <- sampleRegular(x, size=maxpixels, extent=extent, asRaster=TRUE, corners=TRUE)
+		value <- t((getValues(x, format='matrix'))[nrow(x):1,])
 		y <- yFromRow(x, nrow(x):1)
 		x <- xFromCol(x,1:ncol(x))
 		persp(x=x, y=y, z=value, ...)
@@ -26,10 +19,11 @@ setMethod("persp", signature(x='RasterLayer'),
 )
 
 setMethod("persp", signature(x='RasterStackBrick'), 
-	function(x, y=1, maxpixels=1000, ...)  {
+	function(x, y=1, maxpixels=10000, extent=NULL, ...)  {
 		if (y < 1) { y <- 1 }
 		if (y > nlayers(x)) { y <- nlayers(x) }
-		persp(x=x, y=y, maxpixels=maxpixels, ...)
+		x <- raster(x, y)
+		persp(x=x, maxpixels=maxpixels, extent=extent, ...)
 	}	
 )
 
