@@ -68,12 +68,12 @@ polygonValues <- function(p, x, ...) {
 			i <- sapply(res, is.null)
 			if (nlayers(x) > 1) {
 				j <- matrix(ncol=nlayers(x), nrow=length(res))
-				j[!i] <- t(sapply(res[!i], function(x) apply(x, 2, fun, na.rm)))
+				j[!i] <- t(sapply(res[!i], function(x) apply(x, 2, FUN=fun, na.rm=na.rm)))
 				colnames(j) <- layerNames(x)
 			} else {
 				j <- vector(length=length(i))
 				j[i] <- NA
-				j[!i] <- sapply(res[!i], fun, na.rm)
+				j[!i] <- sapply(res[!i], FUN=fun, na.rm=na.rm)
 			}
 			res <- j
 		}
