@@ -19,6 +19,11 @@ setMethod('readAll', signature(object='RasterLayer'),
 		}
 		object@data@values <- .readRasterLayerValues(object, 1, object@nrows)
 		object@data@inmemory <- TRUE
+		on.exit( options('warn'= getOption('warn')) )
+		options('warn'=-1) 
+		object@data@min <- as.vector( min(object@data@values, na.rm=TRUE ) )
+		object@data@max <- as.vector( max(object@data@values, na.rm=TRUE ) )
+		object@data@haveminmax <- TRUE
 		return(object)
 	}
 )
@@ -44,6 +49,9 @@ setMethod('readAll', signature(object='RasterBrick'),
 
 		object@data@inmemory <- TRUE
 		object@data@values <- .readRasterBrickValues(object, 1, object@nrows)
+		rge <- apply(object@data@values, 2, FUN=function(x){ range(x, na.rm=TRUE) } )
+		object@data@min <- as.vector(rge[1,])
+		object@data@max <- as.vector(rge[2,])
 		return(object)
 	}
 )
